package SPVM::Sys::Signal::Constant;

1;

=head1 Name

SPVM::Sys::Signal::Constant - Sys::Signal::Constant is a SPVM module

=head1 Usage

  use Sys::Signal::Constant;
  
=head1 Description

C<Sys::Signal::Constant> is a L<SPVM> module.

=head1 Class Methods

=head2 BUS_ADRALN

  static method BUS_ADRALN : int ();

Get the constant value of C<BUS_ADRALN>. If the system doesn't define this constant, an exception will be thrown. The error code is set to the class id of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 BUS_ADRERR

  static method BUS_ADRERR : int ();

Get the constant value of C<BUS_ADRERR>. If the system doesn't define this constant, an exception will be thrown. The error code is set to the class id of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 BUS_MCEERR_AO

  static method BUS_MCEERR_AO : int ();

Get the constant value of C<BUS_MCEERR_AO>. If the system doesn't define this constant, an exception will be thrown. The error code is set to the class id of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 BUS_MCEERR_AR

  static method BUS_MCEERR_AR : int ();

Get the constant value of C<BUS_MCEERR_AR>. If the system doesn't define this constant, an exception will be thrown. The error code is set to the class id of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 BUS_MCERR_

  static method BUS_MCERR_ : int ();

Get the constant value of C<BUS_MCERR_>. If the system doesn't define this constant, an exception will be thrown. The error code is set to the class id of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 BUS_OBJERR

  static method BUS_OBJERR : int ();

Get the constant value of C<BUS_OBJERR>. If the system doesn't define this constant, an exception will be thrown. The error code is set to the class id of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 CLD_CONTINUED

  static method CLD_CONTINUED : int ();

Get the constant value of C<CLD_CONTINUED>. If the system doesn't define this constant, an exception will be thrown. The error code is set to the class id of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 CLD_DUMPED

  static method CLD_DUMPED : int ();

Get the constant value of C<CLD_DUMPED>. If the system doesn't define this constant, an exception will be thrown. The error code is set to the class id of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 CLD_EXITED

  static method CLD_EXITED : int ();

Get the constant value of C<CLD_EXITED>. If the system doesn't define this constant, an exception will be thrown. The error code is set to the class id of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 CLD_KILLED

  static method CLD_KILLED : int ();

Get the constant value of C<CLD_KILLED>. If the system doesn't define this constant, an exception will be thrown. The error code is set to the class id of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 CLD_STOPPED

  static method CLD_STOPPED : int ();

Get the constant value of C<CLD_STOPPED>. If the system doesn't define this constant, an exception will be thrown. The error code is set to the class id of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 CLD_TRAPPED

  static method CLD_TRAPPED : int ();

Get the constant value of C<CLD_TRAPPED>. If the system doesn't define this constant, an exception will be thrown. The error code is set to the class id of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 FPE_FLTDIV

  static method FPE_FLTDIV : int ();

Get the constant value of C<FPE_FLTDIV>. If the system doesn't define this constant, an exception will be thrown. The error code is set to the class id of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 FPE_FLTINV

  static method FPE_FLTINV : int ();

Get the constant value of C<FPE_FLTINV>. If the system doesn't define this constant, an exception will be thrown. The error code is set to the class id of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 FPE_FLTOVF

  static method FPE_FLTOVF : int ();

Get the constant value of C<FPE_FLTOVF>. If the system doesn't define this constant, an exception will be thrown. The error code is set to the class id of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 FPE_FLTRES

  static method FPE_FLTRES : int ();

Get the constant value of C<FPE_FLTRES>. If the system doesn't define this constant, an exception will be thrown. The error code is set to the class id of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 FPE_FLTSUB

  static method FPE_FLTSUB : int ();

Get the constant value of C<FPE_FLTSUB>. If the system doesn't define this constant, an exception will be thrown. The error code is set to the class id of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 FPE_FLTUND

  static method FPE_FLTUND : int ();

Get the constant value of C<FPE_FLTUND>. If the system doesn't define this constant, an exception will be thrown. The error code is set to the class id of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 FPE_INTDIV

  static method FPE_INTDIV : int ();

Get the constant value of C<FPE_INTDIV>. If the system doesn't define this constant, an exception will be thrown. The error code is set to the class id of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 FPE_INTOVF

  static method FPE_INTOVF : int ();

Get the constant value of C<FPE_INTOVF>. If the system doesn't define this constant, an exception will be thrown. The error code is set to the class id of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 FUTEX_WAIT

  static method FUTEX_WAIT : int ();

Get the constant value of C<FUTEX_WAIT>. If the system doesn't define this constant, an exception will be thrown. The error code is set to the class id of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 ILL_BADSTK

  static method ILL_BADSTK : int ();

Get the constant value of C<ILL_BADSTK>. If the system doesn't define this constant, an exception will be thrown. The error code is set to the class id of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 ILL_COPROC

  static method ILL_COPROC : int ();

Get the constant value of C<ILL_COPROC>. If the system doesn't define this constant, an exception will be thrown. The error code is set to the class id of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 ILL_ILLADR

  static method ILL_ILLADR : int ();

Get the constant value of C<ILL_ILLADR>. If the system doesn't define this constant, an exception will be thrown. The error code is set to the class id of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 ILL_ILLOPC

  static method ILL_ILLOPC : int ();

Get the constant value of C<ILL_ILLOPC>. If the system doesn't define this constant, an exception will be thrown. The error code is set to the class id of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 ILL_ILLOPN

  static method ILL_ILLOPN : int ();

Get the constant value of C<ILL_ILLOPN>. If the system doesn't define this constant, an exception will be thrown. The error code is set to the class id of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 ILL_ILLTRP

  static method ILL_ILLTRP : int ();

Get the constant value of C<ILL_ILLTRP>. If the system doesn't define this constant, an exception will be thrown. The error code is set to the class id of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 ILL_PRVOPC

  static method ILL_PRVOPC : int ();

Get the constant value of C<ILL_PRVOPC>. If the system doesn't define this constant, an exception will be thrown. The error code is set to the class id of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 ILL_PRVREG

  static method ILL_PRVREG : int ();

Get the constant value of C<ILL_PRVREG>. If the system doesn't define this constant, an exception will be thrown. The error code is set to the class id of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 POLL_ERR

  static method POLL_ERR : int ();

Get the constant value of C<POLL_ERR>. If the system doesn't define this constant, an exception will be thrown. The error code is set to the class id of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 POLL_HUP

  static method POLL_HUP : int ();

Get the constant value of C<POLL_HUP>. If the system doesn't define this constant, an exception will be thrown. The error code is set to the class id of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 POLL_IN

  static method POLL_IN : int ();

Get the constant value of C<POLL_IN>. If the system doesn't define this constant, an exception will be thrown. The error code is set to the class id of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 POLL_MSG

  static method POLL_MSG : int ();

Get the constant value of C<POLL_MSG>. If the system doesn't define this constant, an exception will be thrown. The error code is set to the class id of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 POLL_OUT

  static method POLL_OUT : int ();

Get the constant value of C<POLL_OUT>. If the system doesn't define this constant, an exception will be thrown. The error code is set to the class id of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 POLL_PRI

  static method POLL_PRI : int ();

Get the constant value of C<POLL_PRI>. If the system doesn't define this constant, an exception will be thrown. The error code is set to the class id of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SI_ASYNCIO

  static method SI_ASYNCIO : int ();

Get the constant value of C<SI_ASYNCIO>. If the system doesn't define this constant, an exception will be thrown. The error code is set to the class id of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SI_KERNEL

  static method SI_KERNEL : int ();

Get the constant value of C<SI_KERNEL>. If the system doesn't define this constant, an exception will be thrown. The error code is set to the class id of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SI_MESGQ

  static method SI_MESGQ : int ();

Get the constant value of C<SI_MESGQ>. If the system doesn't define this constant, an exception will be thrown. The error code is set to the class id of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SI_QUEUE

  static method SI_QUEUE : int ();

Get the constant value of C<SI_QUEUE>. If the system doesn't define this constant, an exception will be thrown. The error code is set to the class id of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SI_SIGIO

  static method SI_SIGIO : int ();

Get the constant value of C<SI_SIGIO>. If the system doesn't define this constant, an exception will be thrown. The error code is set to the class id of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SI_TIMER

  static method SI_TIMER : int ();

Get the constant value of C<SI_TIMER>. If the system doesn't define this constant, an exception will be thrown. The error code is set to the class id of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SI_TKILL

  static method SI_TKILL : int ();

Get the constant value of C<SI_TKILL>. If the system doesn't define this constant, an exception will be thrown. The error code is set to the class id of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SI_USER

  static method SI_USER : int ();

Get the constant value of C<SI_USER>. If the system doesn't define this constant, an exception will be thrown. The error code is set to the class id of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 TRAP_BRANCH

  static method TRAP_BRANCH : int ();

Get the constant value of C<TRAP_BRANCH>. If the system doesn't define this constant, an exception will be thrown. The error code is set to the class id of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 TRAP_BRKPT

  static method TRAP_BRKPT : int ();

Get the constant value of C<TRAP_BRKPT>. If the system doesn't define this constant, an exception will be thrown. The error code is set to the class id of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 TRAP_HWBKPT

  static method TRAP_HWBKPT : int ();

Get the constant value of C<TRAP_HWBKPT>. If the system doesn't define this constant, an exception will be thrown. The error code is set to the class id of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 TRAP_TRACE

  static method TRAP_TRACE : int ();

Get the constant value of C<TRAP_TRACE>. If the system doesn't define this constant, an exception will be thrown. The error code is set to the class id of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SIGABRT

  static method SIGABRT : int ();

Get the constant value of C<SIGABRT>. If the system doesn't define this constant, an exception will be thrown. The error code is set to the class id of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SIGALRM

  static method SIGALRM : int ();

Get the constant value of C<SIGALRM>. If the system doesn't define this constant, an exception will be thrown. The error code is set to the class id of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SIGBUS

  static method SIGBUS : int ();

Get the constant value of C<SIGBUS>. If the system doesn't define this constant, an exception will be thrown. The error code is set to the class id of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SIGCHLD

  static method SIGCHLD : int ();

Get the constant value of C<SIGCHLD>. If the system doesn't define this constant, an exception will be thrown. The error code is set to the class id of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SIGCONT

  static method SIGCONT : int ();

Get the constant value of C<SIGCONT>. If the system doesn't define this constant, an exception will be thrown. The error code is set to the class id of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SIGFPE

  static method SIGFPE : int ();

Get the constant value of C<SIGFPE>. If the system doesn't define this constant, an exception will be thrown. The error code is set to the class id of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SIGHUP

  static method SIGHUP : int ();

Get the constant value of C<SIGHUP>. If the system doesn't define this constant, an exception will be thrown. The error code is set to the class id of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SIGILL

  static method SIGILL : int ();

Get the constant value of C<SIGILL>. If the system doesn't define this constant, an exception will be thrown. The error code is set to the class id of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SIGINT

  static method SIGINT : int ();

Get the constant value of C<SIGINT>. If the system doesn't define this constant, an exception will be thrown. The error code is set to the class id of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SIGIO

  static method SIGIO : int ();

Get the constant value of C<SIGIO>. If the system doesn't define this constant, an exception will be thrown. The error code is set to the class id of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SIGKILL

  static method SIGKILL : int ();

Get the constant value of C<SIGKILL>. If the system doesn't define this constant, an exception will be thrown. The error code is set to the class id of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SIGPIPE

  static method SIGPIPE : int ();

Get the constant value of C<SIGPIPE>. If the system doesn't define this constant, an exception will be thrown. The error code is set to the class id of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SIGPROF

  static method SIGPROF : int ();

Get the constant value of C<SIGPROF>. If the system doesn't define this constant, an exception will be thrown. The error code is set to the class id of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SIGPWR

  static method SIGPWR : int ();

Get the constant value of C<SIGPWR>. If the system doesn't define this constant, an exception will be thrown. The error code is set to the class id of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SIGQUIT

  static method SIGQUIT : int ();

Get the constant value of C<SIGQUIT>. If the system doesn't define this constant, an exception will be thrown. The error code is set to the class id of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SIGRTMAX

  static method SIGRTMAX : int ();

Get the constant value of C<SIGRTMAX>. If the system doesn't define this constant, an exception will be thrown. The error code is set to the class id of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SIGRTMIN

  static method SIGRTMIN : int ();

Get the constant value of C<SIGRTMIN>. If the system doesn't define this constant, an exception will be thrown. The error code is set to the class id of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SIGSEGV

  static method SIGSEGV : int ();

Get the constant value of C<SIGSEGV>. If the system doesn't define this constant, an exception will be thrown. The error code is set to the class id of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SIGSTKFLT

  static method SIGSTKFLT : int ();

Get the constant value of C<SIGSTKFLT>. If the system doesn't define this constant, an exception will be thrown. The error code is set to the class id of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SIGSTOP

  static method SIGSTOP : int ();

Get the constant value of C<SIGSTOP>. If the system doesn't define this constant, an exception will be thrown. The error code is set to the class id of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SIGSYS

  static method SIGSYS : int ();

Get the constant value of C<SIGSYS>. If the system doesn't define this constant, an exception will be thrown. The error code is set to the class id of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SIGTERM

  static method SIGTERM : int ();

Get the constant value of C<SIGTERM>. If the system doesn't define this constant, an exception will be thrown. The error code is set to the class id of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SIGTRAP

  static method SIGTRAP : int ();

Get the constant value of C<SIGTRAP>. If the system doesn't define this constant, an exception will be thrown. The error code is set to the class id of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SIGTSTP

  static method SIGTSTP : int ();

Get the constant value of C<SIGTSTP>. If the system doesn't define this constant, an exception will be thrown. The error code is set to the class id of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SIGTTIN

  static method SIGTTIN : int ();

Get the constant value of C<SIGTTIN>. If the system doesn't define this constant, an exception will be thrown. The error code is set to the class id of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SIGTTOU

  static method SIGTTOU : int ();

Get the constant value of C<SIGTTOU>. If the system doesn't define this constant, an exception will be thrown. The error code is set to the class id of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SIGURG

  static method SIGURG : int ();

Get the constant value of C<SIGURG>. If the system doesn't define this constant, an exception will be thrown. The error code is set to the class id of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SIGUSR1

  static method SIGUSR1 : int ();

Get the constant value of C<SIGUSR1>. If the system doesn't define this constant, an exception will be thrown. The error code is set to the class id of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SIGUSR2

  static method SIGUSR2 : int ();

Get the constant value of C<SIGUSR2>. If the system doesn't define this constant, an exception will be thrown. The error code is set to the class id of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SIGVTALRM

  static method SIGVTALRM : int ();

Get the constant value of C<SIGVTALRM>. If the system doesn't define this constant, an exception will be thrown. The error code is set to the class id of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SIGWINCH

  static method SIGWINCH : int ();

Get the constant value of C<SIGWINCH>. If the system doesn't define this constant, an exception will be thrown. The error code is set to the class id of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SIGXCPU

  static method SIGXCPU : int ();

Get the constant value of C<SIGXCPU>. If the system doesn't define this constant, an exception will be thrown. The error code is set to the class id of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SIGXFSZ

  static method SIGXFSZ : int ();

Get the constant value of C<SIGXFSZ>. If the system doesn't define this constant, an exception will be thrown. The error code is set to the class id of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SIG_DFL

  static method SIG_DFL : int ();

Get the constant value of C<SIG_DFL>. If the system doesn't define this constant, an exception will be thrown. The error code is set to the class id of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SIG_ERR

  static method SIG_ERR : int ();

Get the constant value of C<SIG_ERR>. If the system doesn't define this constant, an exception will be thrown. The error code is set to the class id of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 SIG_IGN

  static method SIG_IGN : int ();

Get the constant value of C<SIG_IGN>. If the system doesn't define this constant, an exception will be thrown. The error code is set to the class id of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

