package SPVM::Sys::Signal::Handler;

our $VERSION = '0.01';

1;

=head1 Name

SPVM::Sys::Signal::Handler - Sys::Signal::Handler is a SPVM module

=head1 Usage

  use Sys::Signal::Handler;
  
=head1 Description

C<Sys::Signal::Handler> is a L<SPVM> module.

=head1 Fields



=head1 Class Methods



=head1 Instance Methods



=head1 Repository



=head1 Author

Yuki Kimoto C<kimoto.yuki@gmail.com>

=head1 Copyright & License

Copyright 2022-2022 Yuki Kimoto, all rights reserved.

This program is free software; you can redistribute it and/or modify it
under the same terms as Perl itself.

