package SPVM::Sys::Signal::Handler::Monitor;

1;

=head1 Name

SPVM::Sys::Signal::Handler::Monitor - Signal Handler to Monitor Signals

=head1 Usage

  use Sys::Signal::Handler::Monitor;

=head1 Description

C<Sys::Signal::Handler::Monitor> is a signal handler to monitor signals.

See L<signal(2) - Linux man page|https://linux.die.net/man/2/signal> in Linux.

See L<Sys::Signal|SPVM::Sys::Signal> about the details of signals.
